@@ -40,8 +40,8 @@ _tc_activation() {
         return 1
         ;;
     esac
-    eval oldval="\$$thing"
-    if [ -n "${oldval}" ]; then
+    eval oldval="\${$thing:-}"
+    if [ -n "${oldval:-}" ]; then
       eval export "${to}'${thing}'=\"${oldval}\""
     else
       eval unset '${to}${thing}'
@@ -144,15 +144,15 @@ if [ "" = "1" ]; then
   _CMAKE_ARGS="${_CMAKE_ARGS} -DCMAKE_SYSTEM_NAME=Linux -DCMAKE_SYSTEM_PROCESSOR=x86_64"
   # shellcheck disable=SC2050 # templating will fix this error
   if [ "Linux" = "Darwin" ]; then
-    _CMAKE_ARGS="${_CMAKE_ARGS} -DCMAKE_SYSTEM_VERSION="
+    _CMAKE_ARGS="${_CMAKE_ARGS} -DCMAKE_SYSTEM_VERSION=0"
   fi
   _MESON_ARGS="${_MESON_ARGS} --cross-file=${CONDA_PREFIX}/meson_cross_file.txt"
   echo "[host_machine]" > "${CONDA_PREFIX}/meson_cross_file.txt"
-  echo "system = ''" >> "${CONDA_PREFIX}/meson_cross_file.txt"
+  echo "system = 'linux'" >> "${CONDA_PREFIX}/meson_cross_file.txt"
   echo "cpu = 'x86_64'" >> "${CONDA_PREFIX}/meson_cross_file.txt"
   echo "cpu_family = 'x86_64'" >> "${CONDA_PREFIX}/meson_cross_file.txt"
   echo "endian = 'little'" >> "${CONDA_PREFIX}/meson_cross_file.txt"
-  if [ "" = "darwin" ]; then
+  if [ "linux" = "darwin" ]; then
     # meson guesses whether it can run binaries in cross-compilation based on some heuristics,
     # and those can be wrong; see https://mesonbuild.com/Cross-compilation.html#properties
     echo "[properties]" >> "${CONDA_PREFIX}/meson_cross_file.txt"
